@@ -50,3 +50,7 @@ def flask_sketch():
     finally:
         if tb:
             print("\n\n", tb)
+
+
+if __name__ == "__main__":
+    flask_sketch()
