@@ -1,8 +1,6 @@
-from flask_sketch.utils import (
-    Sketch,
-    GenericHandler,
-    pjoin,
-)
+from os.path import join as pjoin
+from flask_sketch.sketch import Sketch
+from flask_sketch.utils import GenericHandler
 from flask_sketch import templates
 
 
