@@ -1,13 +1,11 @@
-from flask_sketch.utils import (
-    Sketch,
-    GenericHandler,
-    pjoin,
-)
+from os.path import join as pjoin
 import os
+from flask_sketch.sketch import Sketch
+from flask_sketch.utils import GenericHandler
 
 
 def app_handler(sketch: Sketch):
-    if sketch.app_type == "web_and_api":
+    if sketch.have_api:
         sketch.blueprints.extend(["api"])
         os.makedirs(pjoin(sketch.app_folder, "api", "resources"))
         open(pjoin(sketch.app_folder, "api", "__init__.py"), "a").close()
